@@ -129,4 +129,7 @@ export * from './UserDesignation';
 export * from './SyncLookup';
 export * from './DebugLog';
 export * from './SyncDeviceTick';
+export * from './SyncLookupTick';
+
 export * from './AccessLog';
+export * from './ChangeLog';
